/**
 *
 */
package cdo.spring.demo;

import org.eclipse.emf.cdo.CDOSession;
import org.eclipse.emf.cdo.CDOSessionConfiguration;
import org.eclipse.emf.cdo.CDOTransaction;
import org.eclipse.emf.cdo.eresource.CDOResource;
import org.eclipse.emf.cdo.util.CDOUtil;
import org.eclipse.net4j.Net4jUtil;
import org.eclipse.net4j.connector.IConnector;
import org.eclipse.net4j.tcp.TCPUtil;
import org.eclipse.net4j.util.container.ContainerUtil;
import org.eclipse.net4j.util.container.IManagedContainer;
import org.eclipse.net4j.util.om.OMPlatform;
import org.eclipse.net4j.util.om.log.PrintLogHandler;
import org.eclipse.net4j.util.om.trace.PrintTraceHandler;
import sample.Course;
import sample.Faculty;
import sample.SampleFactory;
import sample.SamplePackage;
import sample.Student;

/**
 * @author PhaneeshN
 *
 */
public class CDOClient {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		 // Enable logging and tracing
	    OMPlatform.INSTANCE.setDebugging(true);
	    OMPlatform.INSTANCE.addLogHandler(PrintLogHandler.CONSOLE);
	    OMPlatform.INSTANCE.addTraceHandler(PrintTraceHandler.CONSOLE);

	    // Prepare container
	    IManagedContainer container = ContainerUtil.createContainer();
	    Net4jUtil.prepareContainer(container); // Register Net4j factories
	    TCPUtil.prepareContainer(container); // Register TCP factories
	    CDOUtil.prepareContainer(container, false); // Register CDO factories
	    //container.

	    // Create connector
	    IConnector connector = TCPUtil.getConnector(container, "localhost:2036");

	    // Create configuration
	    CDOSessionConfiguration configuration = CDOUtil.createSessionConfiguration();
	    configuration.setConnector(connector);
	    configuration.setRepositoryName("repo1");

	    // Open session
	    CDOSession session = configuration.openSession();
	    session.getPackageRegistry().putEPackage(SamplePackage.eINSTANCE);

	    // Open transaction
	    CDOTransaction transaction = session.openTransaction();

	    // Get or create resource
	    CDOResource resource = transaction.getOrCreateResource("/college3");

	    // Work with the resource and commit the transaction
	    Faculty faculty = SampleFactory.eINSTANCE.createFaculty();
	    faculty.setName("Faculty X");

	    Course course = SampleFactory.eINSTANCE.createCourse();
	    course.setName("Course X");
	    faculty.getCourse().add(course);

	    Student student = SampleFactory.eINSTANCE.createStudent();
	    student.setName("Student X");
	    student.setCourse(course);
	    resource.getContents().add(faculty);
	    resource.getContents().add(student);
	    transaction.commit();

	    // Cleanup
	    session.close();
	    connector.disconnect();
	}

}
